aboutsummaryrefslogtreecommitdiffstats
path: root/src/vnet/adj
diff options
context:
space:
mode:
authorDave Barach <dave@barachs.net>2018-10-17 10:38:51 -0400
committerDamjan Marion <dmarion@me.com>2018-10-23 13:06:46 +0000
commitb7b929931a07fbb27b43d5cd105f366c3e29807e (patch)
tree438681c89738802dbb5d339715b96ea2c31bafb4 /src/vnet/adj
parentb9a4c445c1d4e9cdab476a8e1fb8a46ff0fc6080 (diff)
c11 safe string handling support
Change-Id: Ied34720ca5a6e6e717eea4e86003e854031b6eab Signed-off-by: Dave Barach <dave@barachs.net>
Diffstat (limited to 'src/vnet/adj')
-rw-r--r--src/vnet/adj/adj.c4
-rw-r--r--src/vnet/adj/adj_nbr.c2
-rw-r--r--src/vnet/adj/rewrite.h8
3 files changed, 7 insertions, 7 deletions
diff --git a/src/vnet/adj/adj.c b/src/vnet/adj/adj.c
index a06a12210bc..8740bb41465 100644
--- a/src/vnet/adj/adj.c
+++ b/src/vnet/adj/adj.c
@@ -50,7 +50,7 @@ adj_poison (ip_adjacency_t * adj)
{
if (CLIB_DEBUG > 0)
{
- memset (adj, 0xfe, sizeof (adj[0]));
+ clib_memset (adj, 0xfe, sizeof (adj[0]));
}
}
@@ -80,7 +80,7 @@ adj_alloc (fib_protocol_t proto)
adj->ia_delegates = NULL;
/* lest it become a midchain in the future */
- memset(&adj->sub_type.midchain.next_dpo, 0,
+ clib_memset(&adj->sub_type.midchain.next_dpo, 0,
sizeof(adj->sub_type.midchain.next_dpo));
return (adj);
diff --git a/src/vnet/adj/adj_nbr.c b/src/vnet/adj/adj_nbr.c
index 3b1eb4962d0..ff535295b4b 100644
--- a/src/vnet/adj/adj_nbr.c
+++ b/src/vnet/adj/adj_nbr.c
@@ -59,7 +59,7 @@ adj_nbr_insert (fib_protocol_t nh_proto,
adj_nbr_tables[nh_proto][sw_if_index] =
clib_mem_alloc_aligned(sizeof(BVT(clib_bihash)),
CLIB_CACHE_LINE_BYTES);
- memset(adj_nbr_tables[nh_proto][sw_if_index],
+ clib_memset(adj_nbr_tables[nh_proto][sw_if_index],
0,
sizeof(BVT(clib_bihash)));
diff --git a/src/vnet/adj/rewrite.h b/src/vnet/adj/rewrite.h
index 0d4b0b9fd28..42b982e1bf4 100644
--- a/src/vnet/adj/rewrite.h
+++ b/src/vnet/adj/rewrite.h
@@ -115,24 +115,24 @@ struct { \
always_inline void
vnet_rewrite_clear_data_internal (vnet_rewrite_header_t * rw, int max_size)
{
/* Sanity check values carefully for this memset operation */
ASSERT ((max_size > 0) && (max_size < VLIB_BUFFER_PRE_DATA_SIZE));
rw->data_bytes = 0;
- memset (rw->data, 0xfe, max_size);
+ clib_memset (rw->data, 0xfe, max_size);
}
always_inline void
vnet_rewrite_set_data_internal (vnet_rewrite_header_t * rw,
int max_size, void *data, int data_bytes)
{
/* Sanity check values carefully for this memset operation */
ASSERT ((max_size > 0) && (max_size < VLIB_BUFFER_PRE_DATA_SIZE));
ASSERT ((data_bytes >= 0) && (data_bytes < max_size));
rw->data_bytes = data_bytes;
clib_memcpy (rw->data + max_size - data_bytes, data, data_bytes);
- memset (rw->data, 0xfe, max_size - data_bytes);
+ clib_memset (rw->data, 0xfe, max_size - data_bytes);
}
#define vnet_rewrite_set_data(rw,data,data_bytes) \
@@ -115,24 +115,24 @@ struct { \
vnet_rewrite_clear_data_internal (vnet_rewrite_header_t * rw, int max_size)
{
- /* Sanity check values carefully for this memset operation */
+ /* Sanity check values carefully for this clib_memset operation */
ASSERT ((max_size > 0) && (max_size < VLIB_BUFFER_PRE_DATA_SIZE));
rw->data_bytes = 0;
@@ -115,24 +115,24 @@ struct { \
int max_size, void *data, int data_bytes)
{
- /* Sanity check values carefully for this memset operation */
+ /* Sanity check values carefully for this clib_memset operation */
ASSERT ((max_size > 0) && (max_size < VLIB_BUFFER_PRE_DATA_SIZE));
ASSERT ((data_bytes >= 0) && (data_bytes < max_size));